/**
 * @typedef {number[]} bytes An array of 3 (RGB) or 4 (A) values in bytes.
 *
 * All components in the range 0 <= x <= 255
 */
/**
 * Updates a color based on byte values.
 * @alias module:pex-color.fromBytes
 * @param {import("./color.js").color} color
 * @param {bytes} bytes
 * @returns {import("./color.js").color}
 */
export function fromBytes(color: import("./color.js").color, [r, g, b, a]: bytes): import("./color.js").color;
/**
 * Get RGB[A] color components as bytes array.
 * @alias module:pex-color.toBytes
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {bytes}
 */
export function toBytes(color: import("./color.js").color, out?: any[]): bytes;
/**
 * @deprecated Use "fromBytes()".
 * @ignore
 */
export function fromRGBBytes(color: any, bytes: any): import("./color.js").color;
/**
 * @deprecated Use "toBytes()".
 * @ignore
 */
export function toRGBBytes(color: any, out: any): bytes;
/**
 * An array of 3 (RGB) or 4 (A) values in bytes.
 *
 * All components in the range 0 <= x <= 255
 */
export type bytes = number[];
