/**
 * @typedef {number[]} color An array of 3 (RGB) or 4 (A) values.
 *
 * All components in the range 0 <= x <= 1
 */
/**
 * Creates a new color from linear values.
 * @alias module:pex-color.create
 * @param {number} [r=0]
 * @param {number} [g=0]
 * @param {number} [b=0]
 * @param {number} [a]
 * @returns {color}
 */
export function create(r?: number, g?: number, b?: number, a?: number): color;
/**
 * Returns a copy of a color.
 * @alias module:pex-color.copy
 * @param {color} color
 * @returns {color}
 */
export function copy(color: color): color;
/**
 * Sets a color to another color.
 * @alias module:pex-color.set
 * @param {color} color
 * @param {color} color2
 * @returns {color}
 */
export function set(color: color, color2: color): color;
/**
 * Updates a color based on r, g, b, [a] values.
 * @alias module:pex-color.fromValues
 * @param {import("./color.js").color} color
 * @param {number} r
 * @param {number} g
 * @param {number} b
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromValues(color: import("./color.js").color, r: number, g: number, b: number, a?: number): import("./color.js").color;
/**
 * @deprecated Use "fromValues()".
 * @ignore
 */
export function fromRGB(color: any, r: any, g: any, b: any, a: any): color;
/**
 * @deprecated Use "set()".
 * @ignore
 */
export function toRGB(color: any, out?: any[]): color;
/**
 * An array of 3 (RGB) or 4 (A) values.
 *
 * All components in the range 0 <= x <= 1
 */
export type color = number[];
