/**
 * Returns a rgb CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/color}
 * @alias module:pex-color.toCSSRGB
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSRGB(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a linear rgb CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/color}
 * @alias module:pex-color.toCSSRGBLinear
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSRGBLinear(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a P3 rgb CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/color}
 * @alias module:pex-color.toCSSRGBLinear
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSP3(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a hsl CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/hsl}
 * @alias module:pex-color.toCSSHSL
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSHSL(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a hwb CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/hwb}
 * @alias module:pex-color.toCSSHWB
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSHWB(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a lab CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/lab}
 * @alias module:pex-color.toCSSLab
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSLab(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a lab CSS string representation of a given color.
 * @alias module:pex-color.toCSSLab
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSLabD65(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a lch CSS string representation of a given color.
 * @see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/color_value/lch}
 * @alias module:pex-color.toCSSLCH
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSLCH(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a lab CSS string representation of a given color.
 * @alias module:pex-color.toCSSOkLab
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSOkLab(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a lch CSS string representation of a given color.
 * @alias module:pex-color.toCSSOklch
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSOklch(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a xyz-d50 CSS string representation of a given color.
 * @alias module:pex-color.toCSSXYZD50
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSXYZD50(color: import("./color.js").color, precision?: number): css;
/**
 * Returns a xyz (xyz-d65) CSS string representation of a given color.
 * @alias module:pex-color.toCSSXYZ
 * @param {import("./color.js").color} color
 * @param {number} [precision=5]
 * @returns {css}
 */
export function toCSSXYZ(color: import("./color.js").color, precision?: number): css;
/**
 * CSS string representation.
 */
export type css = string;
