/**
 * @typedef {number[]} hpluv CIELUV hue, saturation, lightness.
 *
 * All components in the range 0 <= x <= 1.
 */
/**
 * Updates a color based on HPLuv values and alpha.
 * @alias module:pex-color.fromHPLuv
 * @param {import("./color.js").color} color
 * @param {number} h
 * @param {number} s
 * @param {number} l
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromHPLuv(color: import("./color.js").color, h: number, s: number, l: number, a?: number): import("./color.js").color;
/**
 * Returns a HPLuv representation of a given color.
 * @alias module:pex-color.toHPLuv
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {hpluv}
 */
export function toHPLuv(color: import("./color.js").color, out?: any[]): hpluv;
/**
 * CIELUV hue, saturation, lightness.
 *
 * All components in the range 0 <= x <= 1.
 */
export type hpluv = number[];
