/**
 * @typedef {number[]} hsluv CIELUV hue, saturation, lightness.
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://www.hsluv.org/}
 */
/**
 * Updates a color based on HSLuv values and alpha.
 * @alias module:pex-color.fromHSLuv
 * @param {import("./color.js").color} color
 * @param {number} h
 * @param {number} s
 * @param {number} l
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromHSLuv(color: import("./color.js").color, h: number, s: number, l: number, a?: number): import("./color.js").color;
/**
 * Returns a HSLuv representation of a given color.
 * @alias module:pex-color.toHSLuv
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {hsluv}
 */
export function toHSLuv(color: import("./color.js").color, out?: any[]): hsluv;
/**
 * CIELUV hue, saturation, lightness.
 *
 * All components in the range 0 <= x <= 1
 */
export type hsluv = number[];
