/**
 * @typedef {number[]} hsv hue, saturation, value.
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://en.wikipedia.org/wiki/HSL_and_HSV}
 */
/**
 * Updates a color based on HSV values and alpha.
 * @alias module:pex-color.fromHSV
 * @param {import("./color.js").color} color
 * @param {number} h
 * @param {number} s
 * @param {number} v
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromHSV(color: import("./color.js").color, h: number, s: number, v: number, a?: number): import("./color.js").color;
/**
 * Returns a HSV representation of a given color.
 * @alias module:pex-color.toHSV
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {hsv}
 */
export function toHSV([r, g, b, a]: import("./color.js").color, out?: any[]): hsv;
/**
 * hue, saturation, value.
 *
 * All components in the range 0 <= x <= 1
 */
export type hsv = number[];
