/**
 * @typedef {number[]} hwb hue, whiteness, blackness.
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://en.wikipedia.org/wiki/HWB_color_model}
 */
/**
 * Updates a color based on HWB values and alpha.
 * @alias module:pex-color.fromHWB
 * @param {import("./color.js").color} color
 * @param {number} h
 * @param {number} w
 * @param {number} b
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromHWB(color: import("./color.js").color, h: number, w: number, b: number, a?: number): import("./color.js").color;
/**
 * Returns a HWB representation of a given color.
 * @alias module:pex-color.toHWB
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {hwb}
 */
export function toHWB(color: import("./color.js").color, out?: any[]): hwb;
/**
 * hue, whiteness, blackness.
 *
 * All components in the range 0 <= x <= 1
 */
export type hwb = number[];
