/**
 * @typedef {number[]} lab CIELAB perceptual Lightness, a* red/green, b* blue/yellow.
 *
 * Components range (D65): 0 <= l <= 1; -0.86183 <= a <= 0.98234; -1.0786 <= b <= 0.94478;
 *
 * Components range (D50): 0 <= l <= 1; -0.79287 <= a <= 0.9355; -1.12029 <= b <= 0.93388;
 * @see {@link https://en.wikipedia.org/wiki/CIELAB_color_space}
 */
export function fromLab(color: any, l: any, a: any, b: any, α: any, { illuminant, fromXYZ }?: {
    illuminant?: number[];
    fromXYZ?: typeof fromXYZD50;
}): import("./color.js").color;
export function toLab(color: any, out?: any[], { illuminant, toXYZ }?: {
    illuminant?: number[];
    toXYZ?: typeof toXYZD50;
}): lab;
/**
 * Updates a color based on Lab values and alpha using D50 standard illuminant.
 * @alias module:pex-color.fromLabD50
 * @param {import("./color.js").color} color
 * @param {number} l
 * @param {number} a
 * @param {number} b
 * @param {number} α
 * @returns {import("./color.js").color}
 */
export function fromLabD50(color: import("./color.js").color, l: number, a: number, b: number, α: number): import("./color.js").color;
/**
 * Returns a Lab representation of a given color using D50 standard illuminant.
 * @alias module:pex-color.toLabD50
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {lab}
 */
export function toLabD50(color: import("./color.js").color, out?: any[]): lab;
/**
 * Updates a color based on Lab values and alpha using D65 standard illuminant.
 * @alias module:pex-color.fromLabD65
 * @param {import("./color.js").color} color
 * @param {number} l
 * @param {number} a
 * @param {number} b
 * @param {number} α
 * @returns {import("./color.js").color}
 */
export function fromLabD65(color: import("./color.js").color, l: number, a: number, b: number, α: number): import("./color.js").color;
/**
 * Returns a Lab representation of a given color using D65 standard illuminant.
 * @alias module:pex-color.toLabD65
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {lab}
 */
export function toLabD65(color: import("./color.js").color, out?: any[]): lab;
/**
 * CIELAB perceptual Lightness, a* red/green, b* blue/yellow.
 *
 * Components range (D65): 0 <= l <= 1; -0.86183 <= a <= 0.98234; -1.0786 <= b <= 0.94478;
 *
 * Components range (D50): 0 <= l <= 1; -0.79287 <= a <= 0.9355; -1.12029 <= b <= 0.93388;
 */
export type lab = number[];
import { fromXYZD50 } from "./xyz.js";
import { toXYZD50 } from "./xyz.js";
