/**
 * @typedef {number[]} lchuv CIELChuv Luminance Chroma Hue.
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://en.wikipedia.org/wiki/CIELUV}
 */
/**
 * Updates a color based on LCHuv values and alpha.
 * @alias module:pex-color.fromLCHuv
 * @param {import("./color.js").color} color
 * @param {number} l
 * @param {number} c
 * @param {number} h
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromLCHuv(color: import("./color.js").color, l: number, c: number, h: number, a?: number): import("./color.js").color;
/**
 * Returns a LCHuv representation of a given color.
 * @alias module:pex-color.toLCHuv
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {lchuv}
 */
export function toLCHuv(color: import("./color.js").color, out?: any[]): lchuv;
/**
 * CIELChuv Luminance Chroma Hue.
 *
 * All components in the range 0 <= x <= 1
 */
export type lchuv = number[];
