/**
 * @typedef {number[]} okhsl
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://bottosson.github.io/posts/colorpicker/#hsl-2}
 */
/**
 * Updates a color based on Okhsl values and alpha.
 * @alias module:pex-color.fromOkhsl
 * @param {import("./color.js").color} color
 * @param {number} h
 * @param {number} s
 * @param {number} l
 * @param {number} [α]
 * @returns {import("./color.js").color}
 */
export function fromOkhsl(color: import("./color.js").color, h: number, s: number, l: number, α?: number): import("./color.js").color;
/**
 * Returns an Okhsl representation of a given color.
 * @alias module:pex-color.toOkhsl
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {okhsl}
 */
export function toOkhsl(color: import("./color.js").color, out?: any[]): okhsl;
/**
 * All components in the range 0 <= x <= 1
 */
export type okhsl = number[];
