/**
 * @typedef {number[]} oklch Cylindrical form using D65 standard illuminant.
 *
 * All components in the range 0 <= x <= 1
 * @see {@link https://drafts.csswg.org/css-color/#color-conversion-code}
 */
/**
 * Updates a color based on Oklch values and alpha.
 * @alias module:pex-color.fromOklch
 * @param {import("./color.js").color} color
 * @param {number} l
 * @param {number} c
 * @param {number} h
 * @param {number} [a]
 * @returns {import("./color.js").color}
 */
export function fromOklch(color: import("./color.js").color, l: number, c: number, h: number, a?: number): import("./color.js").color;
/**
 * Returns an Oklch representation of a given color.
 * @alias module:pex-color.toOklch
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {oklch}
 */
export function toOklch(color: import("./color.js").color, out?: any[]): oklch;
/**
 * Cylindrical form using D65 standard illuminant.
 *
 * All components in the range 0 <= x <= 1
 */
export type oklch = number[];
