export function setAlpha(color: any, a: any): any;
export function floorArray(color: any, precision?: number): any;
export const TMP: number[];
export const TAU: number;
/**
 * Illuminant D65: x,y,z tristimulus values
 * @see {@link https://en.wikipedia.org/wiki/Standard_illuminant#White_points_of_standard_illuminants}
 */
export const D65: number[];
/**
 * Illuminant D50: x,y,z tristimulus values
 */
export const D50: number[];
/**
 * Convert component from linear value
 * @param {number} c
 * @returns {number}
 */
export function linearToSrgb(c: number): number;
/**
 * Convert component to linear value
 * @param {number} c
 * @returns {number}
 */
export function srgbToLinear(c: number): number;
/**
 * Return a RGB representation from Linear values.
 * @param {number} lr
 * @param {number} lg
 * @param {number} lb
 * @param {Array} out
 * @returns {import("./color.js").color}
 */
export function linearToRgb(lr: number, lg: number, lb: number, out: any[]): import("./color.js").color;
/**
 * Return a Linear representation from RGB values.
 * @param {number} r
 * @param {number} g
 * @param {number} b
 * @param {Array} out
 * @returns {import("./linear.js").linear}
 */
export function rgbToLinear(r: number, g: number, b: number, out: any[]): import("./linear.js").linear;
/**
 * Return a Linear representation from XYZ values with D65 illuminant.
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {Array} out
 * @returns {import("./linear.js").linear}
 */
export function xyzD65ToLinear(x: number, y: number, z: number, out: any[]): import("./linear.js").linear;
/**
 * Return a XYZ representation with D65 illuminant from Linear values.
 * @param {number} lr
 * @param {number} lg
 * @param {number} lb
 * @param {Array} out
 * @returns {import("./xyz.js").xyz}
 */
export function linearToXyzD65(lr: number, lg: number, lb: number, out: any[]): import("./xyz.js").xyz;
/**
 * Return a Linear representation from XYZ values with D50 illuminant.
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {Array} out
 * @returns {import("./linear.js").linear}
 */
export function xyzD50ToLinear(x: number, y: number, z: number, out: any[]): import("./linear.js").linear;
/**
 * Return a XYZ representation with D50 illuminant from Linear values.
 * @param {number} lr
 * @param {number} lg
 * @param {number} lb
 * @param {Array} out
 * @returns {import("./xyz.js").xyz}
 */
export function linearToXyzD50(lr: number, lg: number, lb: number, out: any[]): import("./xyz.js").xyz;
/**
 * Return a XYZ representation with D65 illuminant from Linear P3 values.
 * @param {number} lr
 * @param {number} lg
 * @param {number} lb
 * @param {Array} out
 * @returns {import("./xyz.js").xyz}
 */
export function linearP3ToXyzD65(lr: number, lg: number, lb: number, out: any[]): import("./xyz.js").xyz;
/**
 * Return a Linear P3 representation from XYZ values with D65 illuminant.
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {Array} out
 * @returns {Array} P3 Linear
 */
export function xyzD65ToLinearP3(x: number, y: number, z: number, out: any[]): any[];
export function xyzToLuv(X: any, Y: any, Z: any, out: any): any;
export function luvToXyz(L: any, U: any, V: any, out: any): any;
export function luvToLch(L: any, U: any, V: any, out: any): any;
export function lchToLuv(L: any, C: any, H: any, out: any): any;
export function hpluvToLch(H: any, S: any, L: any, out: any): any;
export function lchToHpluv(L: any, C: any, H: any, out: any): any;
export function hsluvToLch(H: any, S: any, L: any, out: any): any;
export function lchToHsluv(L: any, C: any, H: any, out: any): any;
/**
 * Return a Lab representation from LCH values.
 * @param {number} l
 * @param {number} c
 * @param {number} h
 * @param {Array} out
 * @returns {import("./lab.js").lab}
 */
export function lchToLab(l: number, c: number, h: number, out: any[]): import("./lab.js").lab;
/**
 * Return a Lch representation from Lab values.
 * @param {number} l
 * @param {number} a
 * @param {number} b
 * @param {Array} out
 * @returns {import("./lch.js").lch}
 */
export function labToLch(l: number, a: number, b: number, out: any[]): import("./lch.js").lch;
/**
 * Return a XYZ representation from Lab values with provided illuminant.
 * @param {number} l
 * @param {number} a
 * @param {number} b
 * @param {Array} out
 * @param {Array} illuminant
 * @returns {import("./xyz.js").xyz}
 */
export function labToXyz(l: number, a: number, b: number, out: any[], illuminant: any[]): import("./xyz.js").xyz;
/**
 * Return a lab representation from XYZ values with provided illuminant.
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {Array} out
 * @param {Array} illuminant
 * @returns {import("./lab.js").lab}
 */
export function xyzToLab(x: number, y: number, z: number, out: any[], illuminant: any[]): import("./lab.js").lab;
/**
 * Return a Linear representation from Oklab values.
 * @param {number} L
 * @param {number} a
 * @param {number} b
 * @param {Array} out
 * @returns {import("./linear.js").linear}
 */
export function oklabToLinear(L: number, a: number, b: number, out: any[]): import("./linear.js").linear;
/**
 * Return a Oklab representation from Linear values.
 * @param {number} lr
 * @param {number} lg
 * @param {number} lb
 * @param {Array} out
 * @returns {import("./oklab.js").oklab}
 */
export function linearToOklab(lr: number, lg: number, lb: number, out: any[]): import("./oklab.js").oklab;
export function toe(x: any): number;
export function toeInv(x: any): number;
export function findCusp(a: any, b: any): number[];
export function getStMax(a_: any, b_: any, cusp?: any): number[];
export function findGamutIntersection(a: any, b: any, L1: any, C1: any, L0: any, cusp?: any): number;
export function getCs(L: any, a_: any, b_: any): number[];
