/**
 * @typedef {number[]} xyz CIE XYZ.
 *
 * Components range: 0 <= x <= 0.95; 0 <= y <= 1; 0 <= z <= 1.08;
 * @see {@link https://en.wikipedia.org/wiki/CIE_1931_color_space}
 */
/**
 * Updates a color based on XYZ values and alpha using D50 standard illuminant.
 * @alias module:pex-color.fromXYZD50
 * @param {import("./color.js").color} color
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {number} a
 * @returns {import("./color.js").color}
 */
export function fromXYZD50(color: import("./color.js").color, x: number, y: number, z: number, a: number): import("./color.js").color;
/**
 * Returns a XYZ representation of a given color using D50 standard illuminant.
 * @alias module:pex-color.toXYZD50
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {xyz}
 */
export function toXYZD50([r, g, b, a]: import("./color.js").color, out?: any[]): xyz;
/**
 * Updates a color based on XYZ values and alpha using D65 standard illuminant.
 * @alias module:pex-color.fromXYZD65
 * @param {import("./color.js").color} color
 * @param {number} x
 * @param {number} y
 * @param {number} z
 * @param {number} a
 * @returns {import("./color.js").color}
 */
export function fromXYZD65(color: import("./color.js").color, x: number, y: number, z: number, a: number): import("./color.js").color;
/**
 * Returns a XYZ representation of a given color using D65 standard illuminant.
 * @alias module:pex-color.toXYZD65
 * @param {import("./color.js").color} color
 * @param {Array} out
 * @returns {xyz}
 */
export function toXYZD65([r, g, b, a]: import("./color.js").color, out?: any[]): xyz;
/**
 * CIE XYZ.
 *
 * Components range: 0 <= x <= 0.95; 0 <= y <= 1; 0 <= z <= 1.08;
 */
export type xyz = number[];
